# roblox.pyc

## [Docs](https://robloxpydocs.vercel.app) | [Docs (github)](https://github.com/AsynchronousAI/robloxpydocs/tree/main) | [Devforum](https://devforum.roblox.com/t/roblox-py-python-luau/2457105?u=dev98799) | [Github](https://github.com/AsynchronousAI/roblox.py) | [Tests/Examples](https://github.com/AsynchronousAI/roblox.py/tree/main/test)
Python compiler for Roblox. 

Python 3.13 (dev) -> Lua(u)

## Why did the name get changed to roblox.pyc?
2 reasons:
- It's a python compiler, so it should be named .py**c**
- Eventually I am planning on adding C support, so it would be confusing to have a compiler named roblox.py that supports C.

## Dependencies
- ``pip3 install --upgrade pyflakes``
- ``pip3 install flask``
- ``pip3 install pyyaml``

## Credits
- [Highlighter](https://github.com/boatbomber/Highlighter). modified to work with python
- [TextBoxPlus](https://github.com/boatbomber/TextBoxPlus). uses a modified version with autocomplete
- [pythonlua](https://github.com/dmitrii-eremin/python-lua). this is heavily modified version with flask implementation and compiler changes.

  (read licenses in [copyright.txt](/COPYRIGHTS.txt))
## Plugin Guide
### #1 - Clone and start server
```
git clone https://github.com/AsynchronousAI/roblox.py/; cd roblox.py; python3 .
```

> Note: This process will end whenever you restart your computer or close the terminal. We recommend using Replit instead.

If any issues occur here report it in github issues.

### #2 - Download client
A download link is in the releases, download the file and place it in your plugins folder. 

You can check where your plugins folder is by:
- opening Roblox Studio
- clicking the Plugins folder icon in the top bar
- and clicking "Plugins Folder"

### #3 Configuring the client
After installing the client open any place, make a new StringValue anywhere named "ROBLOXPY_CONFIG" with its value being the url and then press the roblox.py/Python icon in the plugins tab.

> Note: If you are hosting on a personal computer this step may not be needed because the url is defaulted to localhost:5555

### #4 Open studio and test
Open Roblox Studio, and select any location and click the roblox.py/Python icon in the plugins tab. A window for editing the plugin and a new script named "Script.py" should appear in the explorer.

## CLI Coming soon

### Learn more
Learn more in the devforum post.
